Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(974)

Unified Diff: ios/web/web_state/ui/crw_web_controller.mm

Issue 2762113002: Reading List iOS: Adapt loading offline for new reload process (Closed)
Patch Set: update comment Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ios/web/web_state/ui/crw_web_controller.mm
diff --git a/ios/web/web_state/ui/crw_web_controller.mm b/ios/web/web_state/ui/crw_web_controller.mm
index c15eb0c28b87b3c90437e3146c956e359006209b..c1271b875ffecd904be0c2aa2413897c774a51fe 100644
--- a/ios/web/web_state/ui/crw_web_controller.mm
+++ b/ios/web/web_state/ui/crw_web_controller.mm
@@ -1801,9 +1801,9 @@ const NSTimeInterval kSnapshotOverlayTransition = 0.5;
GURL navUrl = params.url;
ui::PageTransition transition = params.transition_type;
DCHECK(!(transition & ui::PAGE_TRANSITION_FORWARD_BACK));
- // This method is allowed to handle reload only for transient items, which
- // is essentially loading the same URL again.
- DCHECK(!(transition & ui::PAGE_TRANSITION_RELOAD) ||
+ // This method is allowed to handle reload only for transient items and native
+ // content, which is essentially loading the same URL again.
+ DCHECK(self.nativeController || !(transition & ui::PAGE_TRANSITION_RELOAD) ||
self.navigationManagerImpl->GetTransientItem());
BOOL initialNavigation = NO;

Powered by Google App Engine
This is Rietveld 408576698